@@ -1,4 +1,4 @@
-from .ext_element import CSS, SASS, Link, Button, Script
+from .ext_element import CSS, SASS, Link, Button
 from . import ext_utils as util
 from .style import Style, Styler
 from .script import Script, ScriptHandle
\ No newline at end of file
